@@ -150,41 +150,73 @@ class MultiModel(object):
             votes.append_row(prediction_row)
         return votes
 
-    def batch_predict(self, input_data_list, output_file_path,
+    def batch_predict(self, input_data_list, output_file_path=None,
                       by_name=True, reuse=False,
-                      missing_strategy=LAST_PREDICTION):
+                      missing_strategy=LAST_PREDICTION, headers=None,
+                      to_file=True):
         """Makes predictions for a list of input data.
 
-           The predictions generated for each model are stored in an output
+           When the to_file argument is set to True, the predictions
+           generated for each model are stored in an output
            file. The name of the file will use the following syntax:
                 model_[id of the model]__predictions.csv
            For instance, when using model/50c0de043b563519830001c2 to predict,
            the output file name will be
                 model_50c0de043b563519830001c2__predictions.csv
+            On the contrary, if it is False, the function returns a list
+            of MultiVote objects with the model's predictions.
         """
+        add_headers = (isinstance(input_data_list[0], list) and
+                       headers is not None and
+                       len(headers) == len(input_data_list[0]))
+        if not add_headers and not isinstance(input_data_list[0], dict):
+            raise ValueError("Input data list is not a dictionary or the"
+                             " headers and input data information are not"
+                             " consistent.")
+        order = 0
+        if not to_file:
+            votes = []
+
         for model in self.models:
-            output_file = get_predictions_file_name(model.resource_id,
-                                                    output_file_path)
-            if reuse:
+            order += 1
+            if to_file:
+                output_file = get_predictions_file_name(model.resource_id,
+                                                        output_file_path)
+                if reuse:
+                    try:
+                        predictions_file = open(output_file)
+                        predictions_file.close()
+                        continue
+                    except IOError:
+                        pass
                 try:
-                    predictions_file = open(output_file)
-                    predictions_file.close()
-                    continue
+                    predictions_file = csv.writer(open(output_file, 'w', 0),
+                                                  lineterminator="\n")
                 except IOError:
-                    pass
-            try:
-                predictions_file = csv.writer(open(output_file, 'w', 0),
-                                              lineterminator="\n")
-            except IOError:
-                raise Exception("Cannot find %s directory." % output_file_path)
-            for input_data in input_data_list:
+                    raise Exception("Cannot find %s directory." %
+                                    output_file_path)
+
+            for index, input_data in enumerate(input_data_list):
+                if add_headers:
+                    input_data = dict(zip(headers, input_data))
                 prediction = model.predict(input_data,
                                            by_name=by_name,
                                            with_confidence=True,
                                            missing_strategy=missing_strategy)
-                if isinstance(prediction[0], basestring):
-                    prediction[0] = prediction[0].encode("utf-8")
-                predictions_file.writerow(prediction)
+                if to_file:
+                    if isinstance(prediction[0], basestring):
+                        prediction[0] = prediction[0].encode("utf-8")
+                    predictions_file.writerow(prediction)
+                else:
+                    prediction, confidence, distribution, instances = prediction
+                    prediction_row = [prediction, confidence, order,
+                                      distribution, instances]
+                    if len(votes) <= index:
+                        votes.append(MultiVote([]))
+                    votes[index].append_row(prediction_row)
+
+        if not to_file:
+            return votes
 
     def batch_votes(self, predictions_file_path, data_locale=None):
         """Adds the votes for predictions generated by the models.
